@@ -1,6 +1,7 @@
 """Filex."""
 
 import random
+
 from utils import timex
 
 MIN_INT, MAX_INT = 10 ** 15, 10 ** 16 - 1
@@ -25,5 +26,5 @@ def get_tmp_file():
     """Get tmp file name."""
     return '/tmp/tmp.%s.%d' % (
         timex.format_time(timex.get_unixtime(), '%Y%m%d%H%M%S'),
-        random.randint(MIN_INT, MAX_INT)
+        random.randint(MIN_INT, MAX_INT),
     )
